@@ -137,10 +137,10 @@ DVBase[VITC] = 60;
 DVBase[FASAT] = 20;
 DVBase[CHOLE] = 300;
 DVBase[VITD] = 400;
-DVBase[LA] = 4.44;
+DVBase[LA] = 6;
 DVBase[AA] = 0.2;
 DVBase[OMEGA6] = DVBase[LA] + DVBase[AA];
-DVBase[ALA] = 2.22;
+DVBase[ALA] = 2;
 DVBase[EPA] = 0.33;
 DVBase[DHA] = 0.33;
 DVBase[OMEGA3] = DVBase[ALA] + DVBase[EPA] + DVBase[DHA];
