@@ -380,7 +380,7 @@ fgets(buff,128,stdin);
 
 void auto_cal(float *bufptr, int analflag)
 {
-float buf = *bufptr, temp = 0, satfatpct = .39;
+float buf = *bufptr, temp = 0;
 int i;
 if (options.autocal) buf = average_cals(analflag);
 if (analflag)
@@ -512,11 +512,17 @@ if (options.abnuts[ZN] > 0) DV[ZN] = options.abnuts[ZN];
 if (! options.abnuts[CHO_NONFIB]) DV[CHO_NONFIB] = DV[CHOCDF] - DV[FIBTG] < 0 ? 0 : DV[CHOCDF] - DV[FIBTG];
 else DV[CHO_NONFIB] = options.abnuts[CHO_NONFIB];
 temp = 1 - (DV[PROCNT] * options.protcalpergm + DV[CHOCDF] * options.carbcalpergm) / DV[ENERC_KCAL];
-if (temp > .3 && options.pcsatfat <= 0 && options.abnuts[FASAT] <= 0 && options.abnuts[FAMS] <= 0) 
+if (temp > .32 && options.pcsatfat <= 0 && options.abnuts[FASAT] <= 0 && options.abnuts[FAMS] <= 0) 
  {
- temp = DV[FAMS] + DV[FASAT];
- if (temp * satfatpct > DV[FASAT]) DV[FASAT] = temp * satfatpct; 
- DV[FAMS] = temp - DV[FASAT];
+ temp = (DV[FASAT] * temp / .3) - DV[FASAT];
+ DV[FASAT] += temp;
+ DV[FAMS] -= temp;
+ if (analflag && food_work.nutrient[FASAT] < DV[FASAT])
+  {
+  temp = (DV[FASAT] + DV[FAMS]) / (food_work.nutrient[FASAT] + food_work.nutrient[FAMS]);
+  DV[FASAT] = food_work.nutrient[FASAT] * temp;
+  DV[FAMS] = food_work.nutrient[FAMS] * temp;
+  }
  }
 if ( options.pcsatfat > 0 || options.pcprotein > 0 || options.pccarb > 0 || options.fatprotratio || options.abnuts[PROCNT] > 0 || options.abnuts[CHOCDF] > 0 || options.abnuts[FIBTG] > 0 || options.abnuts[VITE]) options.custom = 1;
 else options.custom = 0;
@@ -687,8 +693,10 @@ options.defanal = count - count % options.mealsperday;
 void efa_dynamics()
 {
 int i;
-float temp, temp_la = 0, temp_aa = 0, extra_ala = 0, hufapct, p3, h3, h6, p6, o;
-float target = 60, laalaratio = 4.0, epadhalimit = 3.8;
+float temp, temp_la = 0, temp_aa = 0, hufapct, p3, h3, h6, p6, o;
+float target = 61, epadhalimit, extra_ala;
+
+epadhalimit = DV[ENERC_KCAL] * .0077 / 9.02;
 
 if (options.n6hufa != 0)
  {
@@ -698,12 +706,8 @@ if (options.n6hufa != 0)
 
 options.abnuts[AA] = food_work.nutrient[AA];
 options.abnuts[LA] = food_work.nutrient[LA];
-options.abnuts[ALA] = food_work.nutrient[ALA];
-if (options.abnuts[ALA] < food_work.nutrient[LA] / laalaratio)
- {
- extra_ala = food_work.nutrient[LA] / laalaratio - options.abnuts[ALA];
- options.abnuts[ALA] += extra_ala;
- }
+options.abnuts[ALA] = DV[ALA];
+extra_ala = DV[ALA] - food_work.nutrient[ALA];
 p3 = 902 * (food_work.nutrient[SHORT3] + extra_ala) / food_work.nutrient[ENERC_KCAL];
 p6 = 902 * food_work.nutrient[SHORT6] / food_work.nutrient[ENERC_KCAL];
 h6 = 902 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
@@ -743,13 +747,12 @@ if (food_work.nutrient[EPA] > .02 || food_work.nutrient[DHA] > .02 || food_work.
   options.abnuts[AA] -= temp_aa / 902 * food_work.nutrient[ENERC_KCAL];
   options.abnuts[OMEGA6] -= (temp_la + temp_aa) / 902 * food_work.nutrient[ENERC_KCAL];
   }
- if (options.abnuts[OMEGA6] == 0) options.abnuts[OMEGA6] = .01;
- if (options.abnuts[LA] == 0) options.abnuts[LA] = .01;
- if (options.abnuts[AA] == 0) options.abnuts[AA] = .01;
- if (options.abnuts[OMEGA3] == 0) options.abnuts[OMEGA3] = .01;
- if (options.abnuts[ALA] == 0) options.abnuts[ALA] = .01;
- if (options.abnuts[EPA] == 0) options.abnuts[EPA] = .01;
- if (options.abnuts[DHA] == 0) options.abnuts[DHA] = .01;
+ if (options.abnuts[OMEGA6] <= 0) options.abnuts[OMEGA6] = .01;
+ if (options.abnuts[LA] <= 0) options.abnuts[LA] = .01;
+ if (options.abnuts[AA] <= 0) options.abnuts[AA] = .01;
+ if (options.abnuts[OMEGA3] <= 0) options.abnuts[OMEGA3] = .01;
+ if (options.abnuts[EPA] <= 0) options.abnuts[EPA] = .01;
+ if (options.abnuts[DHA] <= 0) options.abnuts[DHA] = .01;
  return;
  }
 else
@@ -771,13 +774,13 @@ else
   options.abnuts[ALA] = temp;
   options.abnuts[EPA] = .01;
   options.abnuts[DHA] = .01;
-  if (options.abnuts[OMEGA6] == 0) options.abnuts[OMEGA6] = .01;
-  if (options.abnuts[LA] == 0) options.abnuts[LA] = .01;
-  if (options.abnuts[AA] == 0) options.abnuts[AA] = .01;
-  if (options.abnuts[OMEGA3] == 0) options.abnuts[OMEGA3] = .01;
-  if (options.abnuts[ALA] == 0) options.abnuts[ALA] = .01;
-  if (options.abnuts[EPA] == 0) options.abnuts[EPA] = .01;
-  if (options.abnuts[DHA] == 0) options.abnuts[DHA] = .01;
+  if (options.abnuts[OMEGA6] <= 0) options.abnuts[OMEGA6] = .01;
+  if (options.abnuts[LA] <= 0) options.abnuts[LA] = .01;
+  if (options.abnuts[AA] <= 0) options.abnuts[AA] = .01;
+  if (options.abnuts[OMEGA3] <= 0) options.abnuts[OMEGA3] = .01;
+  if (options.abnuts[ALA] <= 0) options.abnuts[ALA] = .01;
+  if (options.abnuts[EPA] <= 0) options.abnuts[EPA] = .01;
+  if (options.abnuts[DHA] <= 0) options.abnuts[DHA] = .01;
   return;
   }
  }
