@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 2005 Jim Jozwiak.
+    Copyright (C) 1996-2007 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@ int get_int(void);
 float get_float();
 void get_string(char *, int);
 void get_qty(float *, float *, float *);
+float evaluate_qty(struct food *, char *);
 void get_select(float *);
 void spacer(int);
 void header(char *);
@@ -37,6 +38,7 @@ void key_put(char *);
 void key_encode(char *, char *);
 char *key_take();
 void key_decode(char *, char *);
+void test_signsense(float *);
 int test_for_negative_zero(float *);
 
 #endif
